@@ -3,8 +3,8 @@ from datetime import datetime
 import json
 from decouple import AutoConfig
 import requests
-
-
+import os 
+dir_path = os.path.dirname(os.path.realpath(__file__))
 
 def _log(msg, application, level,execution_time, environment, user_id=None, extra_data=None):
         now =str( int(datetime.now().timestamp()))
@@ -28,6 +28,7 @@ def _notify(msg):
 
 
 def warning(msg, application, execution_time, environment, user_id=None, extra_data=None):
+        print(dir_path)
         config = AutoConfig(search_path='/var/www/html/pytestee')
         print(config('WARNING'))
 
